Module pak

Module pak 

Quake PAK archive manipulation.

Structs

Header
The header of a PAK archive describes where the table is located in the file and its size.
PakFile
Represents a PAK file by filepath and PakManifest Provides methods to iterate over file contents.
PakItem
An iterator item representing a file in a PAK archive.
PakManifest
Represents the header, table, and table directory of a PAK file.
Table
PAK tables act as an index of all files in the archive. Each TableEntry points to its corresponding file data.
TableEntry
A single entry in a PAK Table. Each entry is 64 bytes in size.

Functions

sort_walk_paths
Sorts based on heirarchy and file name
walk_pak_dir
Walks a directory and returns a vector of tuples containing the path and size of each file. Sorts based on heirarchy and file name. This sort order should be maintained in each PAK. Returns: (path: PathBuf, size: u64) Throws Error::ReadDirectory
walk_pak_dir_sync
Walks a directory and returns a vector of tuples containing the path and size of each file. Sorts based on heirarchy and file name. This sort order should be maintained in each PAK. Returns: (path: PathBuf, size: u64) Throws Error::ReadDirectory