PakFile

Struct PakFile 

pub struct PakFile { /* private fields */ }
Represents a PAK file by filepath and PakManifest Provides methods to iterate over file contents.

Implementations

Source

impl PakFile

pub fn new(filepath: PathBuf, manifest: PakManifest) -> Self

pub async fn from_file<P>(filepath: P) -> Result<Self>
where P: AsRef<Path>,

Constructs from a PAK file. Throws Error::OpenPak, Error::ReadPak

pub fn from_file_sync<P>(filepath: P) -> Result<Self>
where P: AsRef<Path>,

Constructs from a PAK file. Throws Error::OpenPak, Error::ReadPak

pub async fn create_from_dir<P>( input_dir: P, manifest: PakManifest, output_filepath: P, ) -> Result<Self>
where P: AsRef<Path>,

Creates a PAK file by copying files from a directory. The manifest for the directory must already have been generated using PakManifest::from_dir.

pub fn create_from_dir_sync<P>( input_dir: P, manifest: PakManifest, output_filepath: P, ) -> Result<Self>
where P: AsRef<Path>,

Creates (writes) a PAK file by copying files from a directory. The manifest for the directory must already have been generated using PakManifest::from_dir_sync.

pub fn extract_sync<P: AsRef<Path>>(&self, dest_dir: P) -> Result<()>

Extracts the contents of the PAK file to the specified directory. Throws Error::CreateDirectory, Error::OpenPak, Error::WritePak

pub async fn extract<P: AsRef<Path>>(&self, dest_dir: P) -> Result<()>

Extracts the contents of the PAK file to the specified directory. Throws Error::CreateDirectory, Error::OpenPak, Error::WritePak

pub fn read_items<'p>(&'p self) -> impl Stream<Item = Result<PakItem<'p>>>

Returns an iterator over each file item in the PAK, including data. Throws Error::OpenPak, Error::ReadPak

pub fn read_items_sync<'p>( &'p self, ) -> Result<impl Iterator<Item = Result<PakItem<'p>>>>

Returns an iterator over each file item in the PAK, including data. Throws Error::OpenPak, Error::ReadPak

pub fn manifest(&self) -> &PakManifest