PakManifest

Struct PakManifest 

pub struct PakManifest { /* private fields */ }
Represents the header, table, and table directory of a PAK file.

Implementations

Source

impl PakManifest

pub fn new(header: Header, table: Table) -> Self

pub async fn read<R>(reader: &mut R) -> Result<Self>
where R: AsyncRead + AsyncSeek + Unpin,

Reads a PAK manifest from an (buffered) reader.

pub fn read_sync<R>(reader: &mut R) -> Result<Self>
where R: Read + Seek,

Reads a PAK manifest from a (buffered) reader.

pub fn from_dir_sync<P: AsRef<Path>>(input_dir: P) -> Result<Self>

Generates a PAK manifest from a directory. Throws Error::NonUtf8Path, Error::FilenameTooLong

pub async fn from_dir<P: AsRef<Path>>(input_dir: P) -> Result<Self>

Generates a PAK manifest from a directory. Throws Error::NonUtf8Path, Error::FilenameTooLong

pub fn from_walk_results(files: Vec<(PathBuf, u64)>) -> Result<Self>

pub fn header(&self) -> &Header

pub fn table(&self) -> &Table

Returns the table (index) of a PAK

pub fn table_entries(&self) -> &Vec<TableEntry>

Returns the table entries of a PAK, including filepath, size, and offset of each item.