Table

Struct Table 

pub struct Table { /* private fields */ }
PAK tables act as an index of all files in the archive. Each TableEntry points to its corresponding file data.

Implementations

Source

impl Table

pub fn new(entries: Vec<TableEntry>) -> Self

pub async fn read<R>(reader: &mut R, header: &Header) -> Result<Self>
where R: AsyncRead + AsyncSeek + Unpin,

Reads a table and its entries from a (buffered) reader.

pub fn read_sync<R>(reader: &mut R, header: &Header) -> Result<Self>
where R: Read + Seek,

Reads a table and its entries from a (buffered) reader.

pub fn entries(&self) -> &Vec<TableEntry>

Retrieves the TableEntry items

pub fn contains<P: AsRef<Path>>(&self, path: P) -> bool

TRUE if the table contains an entry with the given path

pub async fn write<W>(&self, writer: &mut W) -> Result<()>
where W: AsyncWrite + Unpin,

Writes the table and its entries to a (buffered) writer.

pub fn write_sync<W>(&self, writer: &mut W) -> Result<()>
where W: Write,

Writes the table and its entries to a (buffered) writer.