TableEntry

Struct TableEntry 

pub struct TableEntry { /* private fields */ }
A single entry in a PAK Table. Each entry is 64 bytes in size.

Implementations

Source

impl TableEntry

pub fn new(path: String, offset: u32, size: u32) -> Result<Self>

Will throw an Error::FilenameTooLong if the path is greater than 56 characters

pub async fn read<R>(reader: &mut R) -> Result<Self>
where R: AsyncRead + Unpin,

Reads a table entry from a (buffered) reader.

pub fn read_sync<R>(reader: &mut R) -> Result<Self>
where R: Read,

Reads a table entry from a (buffered) reader.

pub fn path(&self) -> &str

Retrieves the path of a table entry as a String. Its stored format is a fixed 56 byte null-terminated UTF-8 string.

pub fn offset(&self) -> u32

Where the table entry file data is located in the file.

pub fn size(&self) -> u32

The size of the table entry file’s data.

pub async fn write<W>(&self, writer: &mut W) -> Result<()>
where W: AsyncWrite + Unpin,

Writes the table entry to a (buffered) writer.

pub fn write_sync<W>(&self, writer: &mut W) -> Result<()>
where W: Write,

Writes the table entry to a (buffered) writer.