pub struct Table { /* private fields */ }Expand description
PAK tables act as an index of all files in the archive. Each TableEntry points to its corresponding file data.
Implementations
Sourceimpl Table
impl Table
pub fn new(entries: Vec<TableEntry>) -> Self
Sourcepub async fn read<R>(reader: &mut R, header: &Header) -> Result<Self>
pub async fn read<R>(reader: &mut R, header: &Header) -> Result<Self>
Reads a table and its entries from a (buffered) reader.
Sourcepub fn read_sync<R>(reader: &mut R, header: &Header) -> Result<Self>
pub fn read_sync<R>(reader: &mut R, header: &Header) -> Result<Self>
Reads a table and its entries from a (buffered) reader.
Sourcepub fn entries(&self) -> &Vec<TableEntry>
pub fn entries(&self) -> &Vec<TableEntry>
Retrieves the TableEntry items
Sourcepub fn contains<P: AsRef<Path>>(&self, path: P) -> bool
pub fn contains<P: AsRef<Path>>(&self, path: P) -> bool
TRUE if the table contains an entry with the given path